==> spider_1.0.01.zip: spider_1.0.01/spider/messages.inc.php <==
<?php
/*
 * framework-spider: メッセージリソース設定ファイル
 */
$GLOBALS['spider.messages']	= array(
	// core
	'spider.controller.moduleisnotfound'				=> 'Core Error: 存在しないモジュール呼び出しです。',
	'spider.httpoutput.busy'							=> 'Core Error: 現在アクセスが非常に混雑しています。しばらくたってからもう一度アクセスしてください。',
	'spider.finctions.libdirisnotfound'				=> 'Core Error : ライブラリディレクトリがありません。',
	'spider.finctions.templatedirisnotfound'			=> 'Core Error : テンプレートディレクトリがありません。',
	'spider.finctions.workdirisnotfound'				=> 'Core Error : ワークディレクトリがありません。',
	'spider.finctions.workdirisnotwritable'			=> 'Core Error : ワークディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatebindir'				=> 'Core Error : ビルドファイル保存ディレクトリを作成できません。',
	'spider.finctions.bindirisnotwritable'			=> 'Core Error : ビルドファイル保存ディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatelockdir'				=> 'Core Error : プロセスロックディレクトリを作成できません。',
	'spider.finctions.lockdirisnotwritable'			=> 'Core Error : プロセスロックディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatetmpdir'				=> 'Core Error : 一時ディレクトリを作成できません。',
	'spider.finctions.tmpdirisnotwritable'			=> 'Core Error : 一時ディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatecachedir'				=> 'Core Error : キャッシュディレクトリを作成できません。',
	'spider.finctions.cachedirisnotwritable'			=> 'Core Error : キャッシュディレクトリが書き込み不能になっています。',
	'spider.finctions.datadirisnotfound'				=> 'Core Error : データディレクトリがありません。',
	'spider.finctions.datadirisnotwritable'			=> 'Core Error : データディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatelogdir'				=> 'Core Error : ログディレクトリを作成できません。',
	'spider.finctions.logdirisnotwritable'			=> 'Core Error : ログディレクトリが書き込み不能になっています。',
	// tags
	'spider.tags.usesession.cantstart'					=> 'Core Error : アプリケーションセッションを開始できませんでした。',
	'spider.tags.write.objectcanthasnumericmember'	=> 'Core Error : オブジェクトの添え字には数字を指定できません。',
);
?>

==> spider_1.1.01.zip: spider_1.1.01/spider/messages.inc.php <==
<?php
/*
 * framework-spider: メッセージリソース設定ファイル
 * @version 1.1.01
 * 
 * CopyRight(C)Framework-Spider Developer Team. 2010. All Right Reserved. 
 * URL         : http://sourceforge.jp/projects/frameworkspider/
 * Mail        : frameworkspider-dev@lists.sourceforge.jp
 * Auther      : Masanori Nakashima
 * Modifier    : Masanori Nakashima
 * Last Updated: 2010.06.23
 * 
 */
$GLOBALS['spider.messages']	= array(
	// core
	'spider.controller.moduleisnotfound'				=> 'Core Error: 存在しないモジュール呼び出しです。',
	'spider.httpoutput.busy'							=> 'Core Error: 現在アクセスが非常に混雑しています。しばらくたってからもう一度アクセスしてください。',
	'spider.finctions.libdirisnotfound'				=> 'Core Error : ライブラリディレクトリがありません。',
	'spider.finctions.templatedirisnotfound'			=> 'Core Error : テンプレートディレクトリがありません。',
	'spider.finctions.workdirisnotfound'				=> 'Core Error : ワークディレクトリがありません。',
	'spider.finctions.workdirisnotwritable'			=> 'Core Error : ワークディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatebindir'				=> 'Core Error : ビルドファイル保存ディレクトリを作成できません。',
	'spider.finctions.bindirisnotwritable'			=> 'Core Error : ビルドファイル保存ディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatelockdir'				=> 'Core Error : プロセスロックディレクトリを作成できません。',
	'spider.finctions.lockdirisnotwritable'			=> 'Core Error : プロセスロックディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatetmpdir'				=> 'Core Error : 一時ディレクトリを作成できません。',
	'spider.finctions.tmpdirisnotwritable'			=> 'Core Error : 一時ディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatecachedir'				=> 'Core Error : キャッシュディレクトリを作成できません。',
	'spider.finctions.cachedirisnotwritable'			=> 'Core Error : キャッシュディレクトリが書き込み不能になっています。',
	'spider.finctions.datadirisnotfound'				=> 'Core Error : データディレクトリがありません。',
	'spider.finctions.datadirisnotwritable'			=> 'Core Error : データディレクトリが書き込み不能になっています。',
	'spider.finctions.cantcreatelogdir'				=> 'Core Error : ログディレクトリを作成できません。',
	'spider.finctions.logdirisnotwritable'			=> 'Core Error : ログディレクトリが書き込み不能になっています。',
	// tags
	'spider.tags.usesession.cantstart'					=> 'Core Error : アプリケーションセッションを開始できませんでした。',
	'spider.tags.write.objectcanthasnumericmember'	=> 'Core Error : オブジェクトの添え字には数字を指定できません。',
);
?>
